@@ -22,6 +22,8 @@
 #include "dynamic_cs.h"
 
 #include"SLHAplus.h"
+
+extern  char * trim(char *);
   
 char  * libDir=NULL;
 char  * modelDir=NULL;
@@ -133,9 +135,8 @@ int  checkMtime(char * fname)
     stat(mfname,&buff);
     if(buff.st_mtime > tt) break;
   }
-
-  if(i<4) {unlink(fname); free(mfname);   return 1;}
   free(mfname);
+  if(i<4) {unlink(fname); return 1;}
   return 0;
 }
 
@@ -234,6 +235,7 @@ numout*getMEcode(int twidth,int Gauge, char*Process, char*excludeVirtual,
    if(twidth) strcat(lib_,"_t");  
    for(test=allProc;test; test=test->next) if(strcmp(lib_,test->libname)==0) 
    {
+     *(test->cc->interface->gtwidth)=0;
      *(test->cc->interface->twidth) =twidth;
      *(test->cc->interface->gswidth)=0;
      *(test->cc->interface->BWrange)=BWrange; 
@@ -337,7 +339,7 @@ static  lVert* loadVert(void* handle, char * lib)
      vv->link=malloc(sizeof(REAL*)*(vv->nVar));
      for(i=0;i<vv->nVar;i++) 
      { char *name=vv->varNames[i];
-       vv->link[i]=varAddress(name);  
+       vv->link[i]=varAddress(name);
      }  
   }
   return vv;
@@ -375,8 +377,7 @@ lVert* getVertex(char*n1,char*n2,char*n3,char*n4)
    int Len;
    char *fields[4]={n1,n2,n3,n4};
 
-   
-   int err=vert2name(fields,lib);      
+   int err=vert2name(fields,lib);
    if(err) return NULL;
    
    for(test=allVert;test; test=test->next) if(strcmp(lib,test->libname)==0)
@@ -402,8 +403,8 @@ lVert* getVertex(char*n1,char*n2,char*n3,char*n4)
         int delWorkDir;
         
         delWorkDir=prepareWorkPlace();
-        sprintf(command,"cd %s; %s/sbin/newVertex models 1  %s  %s %s",
-                       compDir, calchepDir, lib, libDir, vert_txt);                         
+        sprintf(command,"cd %s; %s/sbin/newVertex models  1  %s  %s %s",
+                       compDir, calchepDir,  lib, libDir, vert_txt);
         ret=system(command);
       
 //        if(ret<0 || WIFSIGNALED(ret)>0 ) exit(10);
@@ -441,11 +442,16 @@ int  getNumCoeff(lVert*vv, double * coeff)
 {
    int i;   
    if(!vv) { printf("Call of  getNumCoeff with NULL argument. Program terminated\n"); exit(1);}
-   REAL**link=(REAL**)(vv->link);
-   for(i=0;i<vv->nVar;i++) vv->varValues[i+1]=*(link[i]); 
+ 
+   for(i=0;i<vv->nVar;i++) if(vv->link[i] &&  ((REAL*)(vv->link[i])-varValues) < *currentVarPtr) vv->varValues[i+1]=*((REAL*)(vv->link[i]));
+   else 
+   { 
+     printf("!Value of variable  '%s' needed for calculation of '%s' is not known yet\n",
+     vv->varNames[i], varNames[*currentVarPtr]);  
+     vv->varValues[i]=0; FError=1;
+   }
                                      
    int err= vv->calcCoeff(coeff);
-//   for(i=0;i<vv->vertPtr->nVar;i++) printf("vv->vertPtr->varValues[%d+1]=%E\n",i, vv->vertPtr->varValues[i+1]);   
    return err;
 }
 
@@ -578,7 +584,21 @@ void delAllLib(void)
      curProc=curProc->next;
      free(tmp);
   }
+ 
   allProc=NULL;
+
+  vertRec*curVert=allVert;
+  
+  while(curVert)
+  {  vertRec*tmp=curVert;
+     free(curVert->libname);
+     free(curVert->vv->link);
+     dClose(curVert->vv->handle);
+     curVert=curVert->next;
+     free(tmp);
+  }
+                                       
+  allVert=NULL;
 }
 
 numout*newProcess(char*Process)
@@ -586,7 +606,7 @@ numout*newProcess(char*Process)
    char lib[100];
    err=process2Lib(Process,lib);
    if(err) return NULL;
-   return getMEcode(0,ForceUG,Process,NULL,"",lib);
+   return getMEcode(1,ForceUG,Process,NULL,"",lib);
 }
 
 
@@ -612,12 +632,14 @@ int HiggsLambdas(double Q, char * Higgs, double complex*lAA,double complex *lGG,
    { char Xp[10], Xm[10];
      sscanf(strstr(l->txt,"->")+2, "%[^,],%s",Xp,Xm);
      trim(Xp); trim(Xm); 
+
      if(strcmp(Xp,antiParticle(Xm))==0)
      {  
         int pdg,spin2,charge3,cdim;
         double mX=pMass(Xp);
         double dffE=0,dfaE=0,dffC=0,dfaC=0;
         pdg=qNumbers(Xp, &spin2, &charge3, &cdim);
+
         if((charge3 !=0 || cdim!=1) && mX>0)
         {  
            double coeff[10]; 
