@@ -28,6 +28,16 @@ char * pdg2name(int pdg)
   return NULL;
 } 
 
+char * antiParticle(char*name)
+{  int i; 
+   for(i=0;i<nModelParticles;i++)
+   { if(strcmp(ModelPrtcls[i].name,name)==0) return ModelPrtcls[i].aname;
+     if(strcmp(ModelPrtcls[i].aname,name)==0) return ModelPrtcls[i].name;
+   }      
+   return NULL;
+} 
+
+
 double pMass(char * name)
 {
   char *nm;
