@@ -1,9 +1,11 @@
 #ifndef __FILES_
 #define __FILES_
-#include"syst.h"    
+#include"syst.h"
     extern char * outputDir;
-    extern char pathtocomphep[STRSIZ], _pathtocomphep[STRSIZ];
-    extern char  version[36];
+    extern char pathtocalchep[1024];
     extern void  copyfile(char *   namefrom, char *  nameto);
     extern void nextFileName(char* f_name,char * firstname,char * ext);
+    extern char * unixPath(char *name);
+    extern int findCalcHEPfile(char * name);
+#define f_slash '/'
 #endif
